;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xf504e4d3bb1acc1892c94530e4f8ef99 . "./code.cg2js/cg-common-control.fasl")
(#xcddf842fcd5e5946adbbe831e7ffbced . "./code.cg2js/cg-header-control.fasl")
(#xe2b7073323fabc95b9f8aaa019c9b388 . "./code.cg2js/cg-clipboard-stack.fasl")
(#x35237c24afc6dee52cd7eb1970b83211 . "./code.cg2js/cg-yes-no-string.fasl")
(#x978b3c9e3b6f9ec63229212cabb56c35 . "./code.cg2js/cg-clipboard.fasl")
(#xc2691eb9b686d617816154a8ef69ff6b . "./code.cg2js/cg-dde-utils.fasl")
(#x543f91633d8aaf84c318432b13087420 . "./code.cg2js/cg-editable-text.fasl")
(#xccf1a2341bd08ae14b0ef57a149ee2c4 . "./code.cg2js/cg-text-or-combo.fasl")
(#xe355957453ed8c51275269a9f5601723 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#xcffb7417207c928a5d6efda90c6126b4 . "./code.cg2js/cg-graphics-context.fasl")
(#x66ac176b3101194b6b02a6dc04aac610 . "./code.cg2js/cg-choose-printer.fasl")
(#x1ee6663f804ecfcd0a620311cb0df48c . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x0e30b9eaef0bcc8261ea5f44e645c13f . "./code.cg2js/cg-edit-in-place.fasl")
(#xfc4590bc8936f5ed6b207d859c50b6df . "./code.cg2js/cg-split-bar.fasl")
(#x6bd36553cb7d4e5a41dfbdbbc27bd7f6 . "./code.cg2js/cg-timer.fasl")
(#xb6309db80210815d05c5e54d552f90dd . "./code.cg2js/cg-progress-indicator.fasl")
(#x46c3db4b3efddf1777139239cb67902d . "./code.cg2js/cg-object-editor.fasl")
(#x0ff74abd28a6aac53b7365df02e35d7e . "./code.cg2js/cg-fill-texture.fasl")
(#xa2143c38443ab6e63a5594d145a1ba0f . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#xcecf3e87ce5d7b2f56c48a4056c76f49 . "./code.cg2js/cg-os-window.fasl")
(#x1d16bd96126e7e158d10bbd3138bae9d . "./code.cg2js/cg-color-dialog.fasl")
(#xf5755aea0eecc5d694aaabb8e81aa189 . "./code.cg2js/cg-combo-box.fasl")
(#xa021405aa6ddf8345ea19b89be095d31 . "./code.cg2js/cg-directory-dialog.fasl")
(#xa7b50bb2a612fb1cc2c695c801f6e435 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x406a38f0865da04072f366e9fbe32076 . "./code.cg2js/cg-tooltip.fasl")
(#xc60f69ee3f8e57bed2ce651c5f9cf9c2 . "./code.cg2js/cg-lettered-menu.fasl")
(#xd3b3394bb8da463218dbdc5eb05150d2 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x8fdbab85d610165e3b4221951b3f2fd5 . "./code.cg2js/cg-pixmap.fasl")
(#xd98bf90199b2a1795b98f8ba52f6f273 . "./code.cg2js/cg.fasl")
(#xc89c50c1bc73c26565e870c32da5a088 . "./code.cg2js/cg-class-slot-grid.fasl")
(#x38b46fd1cfbbb748ec49eada06772a66 . "./code.cg2js/cg-template-string.fasl")
(#xc8d5c8edbf55a2a8ba89cd024d8f8874 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x70d434903362729172212ef27c2fdd1d . "./code.cg2js/cg-check-box.fasl")
(#x318cf5dbc38536eda5de1c08c4412471 . "./code.cg2js/cg-toggling-widget.fasl")
(#x8cbb7049237e22eee1c9ffd95eef359a . "./code.cg2js/cg-radio-button.fasl")
(#x10969b3c9e8e095317c2462657e7d7c1 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x53a98d6cfd9e857216adf81920a01ed1 . "./code.cg2js/cg-scaling-stream.fasl")
(#xa93bcb9d200cb9e1e6ffdf7c56f6206b . "./code.cg2js/cg-multi-picture-button.fasl")
(#x8367f8e0d40776720fde5b6e4c760e30 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x5b9f9e21691eae3f61c24c99cfd60ec1 . "./code.cg2js/cg-grid-widget.fasl")
(#x50fda0301390761c6300da9c9c452730 . "./code.cg2js/cg-text-edit-pane.fasl")
(#xfe087cc6273a5db963fcb7481fa4d900 . "./code.cg2js/cg-item-list.fasl")
(#x9060247d448bce7bdac3f8cf7f5861fd . "./code.cg2js/cg-paren-matching.fasl")
(#xdaf4be9a92030704ac4ab13b2f8a6a9b . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x7338bef4529b8a58fec877c43cefaf59 . "./code.cg2js/cg-html-dialog.fasl")
(#x26dbe8616e928fa461492b9429ee88a4 . "./code.cg2js/cg-pixmap-widget.fasl")
(#x33781ada0f0789d7176aa907ce46f395 . "./code.cg2js/cg-project-window.fasl")
(#x054e39909adb02d82ca82bf45663af5b . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#xf35dd9cd07fa368a52e24ef0baa79285 . "./code.cg2js/cg-toolbar.fasl")
(#x214ba0db9b539a5689dabb4ac77454f1 . "./code.cg2js/cg-caret.fasl")
(#xdcd25a76814b7e6c3a48fe85770913c6 . "./code.cg2js/cg-scroll-bar.fasl")
(#xd2b2b8b76ba0904dfe0c756cb45f8d95 . "./code.cg2js/cg-web-browser.fasl")
(#x6020eb54297d2db3453420639b2f1f4e . "./code.cg2js/cg-dropping-outline.fasl")
(#x680b81b0deab1f8bed1b9fafee03642b . "./code.cg2js/cg-font-dialog.fasl")
(#xf05b854b8bdd533f5e4a622b543e2f1b . "./code.cg2js/cg-icon-pixmap.fasl")
(#x4fec080a07d30fd2dc50e477898c440f . "./code.cg2js/cg-yes-no-list.fasl")
(#x49b44e9ad064f24b223a8eeef699a838 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x27058c2173602a453d40020df9f1ffeb . "./code.cg2js/cg-lamp.fasl")
(#x1c700d135c523e0a64034877d45b4b09 . "./code.cg2js/cg-drawable.fasl")
(#x1768bd1af250fd45e462545e632acd6f . "./code.cg2js/cg-choice-list.fasl")
(#xb6f496694f6ed86d01089fe67acdd677 . "./code.cg2js/cg-curve.fasl")
(#x5b61e27f2c749d619e0c288780f78235 . "./code.cg2js/cg-base.fasl")
(#x0f8abb32599c51ca7a18bb700aee020a . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x41be82fada95c35ea331a6585b9a0c9f . "./code.cg2js/cg-printing.fasl")
(#x808c7c13a23ae158145289e12886a290 . "./code.cg2js/cg-chart-or-plot.fasl")
(#xe30b023e50d061bc2eea629ae1de797f . "./code.cg2js/cg-hotspot.fasl")
(#xad1e73eb70a7b63864672fa1c05975a4 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x8c1e78e6ebc346aa89f4918fa983c44d . "./code.cg2js/cg-utility-dialog.fasl")
(#x16aa95225c8bd1734237bd2780292b41 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x5bfa19375e64cd6c0fb5d710d7ae295d . "./code.cg2js/cg-comtab.fasl")
(#xfcb9559cd92c601f4538b44ad0eefd92 . "./code.cg2js/cg-os-widget.fasl")
(#x2287a1aad5a320cc771617fcc10b117e . "./code.cg2js/cg-icon.fasl")
(#x53a696e6198dbe30a17387832bed3373 . "./code.cg2js/cg-dev.fasl")
(#xacffc723413e0b094188b45b3c858f63 . "./code.cg2js/cg-calendar.fasl")
(#xcb1244ff2a95e60afce834cb4c79c71d . "./code.cg2js/cg-group-box.fasl")
(#xf802791f9c62e6a9ea7fb9d650da2cba . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xdc79bfd4d033e0f48638173851f4327d . "./code.cg2js/cg-bitmap-pane.fasl")
(#x7ad30832278f7ed4b7df6215c1e08aa3 . "./code.cg2js/cg-drag-and-drop.fasl")
(#xcafd07b79fbabbc5082651d9ebf46afd . "./code.cg2js/cg-nodes.fasl")
(#x4bd5e7b6e398427cbd820045f2dabeff . "./code.cg2js/cg-intersect.fasl")
(#x833b7674eb86d6d6d1cec2aa865f4fc2 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#xbd0d588697c5ac493ddbf9208acdded8 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x802fa294752655df4ea2c6a624f3b558 . "./code.cg2js/cg-class-support.fasl")
(#xe639d7e55154c7075ac4894e8305104e . "./code.cg2js/cg-dialog-item.fasl")
(#x2d492c93547180d0b23acc7b36222e7a . "./code.cg2js/cg-plot-widget.fasl")
(#xf863f77e2face49f9ae047834f922f64 . "./code.cg2js/cg-pixmap-printing.fasl")
(#x4d737b7a98abb1fe9f0601435514097a . "./code.cg2js/cg-up-down-control.fasl")
(#x6d936ec14a1ae71575a5269ec2ef9cc6 . "./code.cg2js/cg-rich-edit.fasl")
(#x9c6bf9d812f79b76aacdda0904191fe8 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x06b558f5f2beefd47b993b724a6851aa . "./code.cg2js/cg-status-bar.fasl")
(#x2d80670e34bf71f7ff98249a3e9b2711 . "./code.cg2js/cg-class-grid.fasl")
(#xfa5d5eeb4395d781acab39303f8011d6 . "./code.cg2js/cg-wrap-string.fasl")
(#x0a6663a2bc07bf50efb3046a86f29637 . "./code.cg2js/cg-layout.fasl")
(#xf0539cb43a15861ef6ac50a4090c1d24 . "./code.cg2js/cg-lisp-widget.fasl")
(#x5d5b80e8eca355fc8c0411f12928a8f7 . "./code.cg2js/cg-button.fasl")
(#xdf55e7060acc661d8cd455baa457c33f . "./code.cg2js/cg-string-dialog.fasl")
(#x9ce33e6a3a432799672fc18e331d33e7 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x982179624da81acca1902a4874a4816f . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x80bcf66d3f452327f705d9859e4a3fef . "./code.cg2js/cg-bitmap-stream.fasl")
(#x7bf75d2f15f74c2ba069f723be838ecf . "./code.cg2js/cg-static-text.fasl")
(#xe1d8336de40b9139daaab8e0d0ba8e87 . "./code.cg2js/cg-outline.fasl")
(#x09e13a8c2c572a80b8f662292b4d02a9 . "./code.cg2js/cg-gesture-emulation.fasl")
(#x3a146a578bffa0233f8da4ef8a616402 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x03b9824f596049757454e00040bc1193 . "./code.cg2js/cg-picture-widget.fasl")
(#x3064f82c5015c26d2998b3e3e4588aaf . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#xfdc82c22acf5a058f905575eb10e08fe . "./code.cg2js/cg-chart-widget.fasl")
(#x822e2fd8f453946ed7e28162f9d18b97 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x3d2819c2960b4db44eee570411c14b9e . "./code.cg2js/cg-lisp-text.fasl")
(#x0eb1390df9aa76efa03d3eb4d90b4e4a . "./code.cg2js/cg-palette.fasl")
(#x81446620c6d447a6c4d905b06d07fd93 . "./code.cg2js/cg-property.fasl")
(#xbac7d13333a82ff02536c99d2b0f3079 . "./code.cg2js/cg-intersect-posbox.fasl")
(#x12f3117eca560befef935532a49f52e8 . "./code.cg2js/cg-file-dialog.fasl")
(#x7c3398e81cb48dfd560885d37f6a865e . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x52bbdb7e4fb714de0b1e6a2b411fa3eb . "./code.cg2js/cg-get-pixmap.fasl")
(#xffc641e15f83f6819d8418c5f0c4ea9b . "./code.cg2js/cg-tray.fasl")
(#x001323a447784c43622a422bddd12463 . "./code.cg2js/cg-acache.fasl")
(#x7675dbb8a5666c044fe9fa54b0d7c183 . "./code.cg2js/cg-message-dialog.fasl")
(#xc5830f8f6b1a1ebc20c2c6581b7283af . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xf7ac9921c6f9a53d7d0419dfe2370a06 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#xbcf9efbee87a3cab46232586a0735ae8 . "./code.cg2js/cg-tab-control.fasl")
(#x52e08c2a88b91753f4044abc9f5aa2e0 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x70a6cb7d71420581e5de2e5b83a1245c . "./code.cg2js/cg-menu-tooltip.fasl")
(#xb5cce6b1bd1764644cd56bc49e5c6f14 . "./code.cg2js/cg-find-string-dialog.fasl")
(#x9ae5bae9e2251f5ade26e446dc3278e9 . "./code.cg2js/cg-menu.fasl")
(#x0e54b1a95fae3cf29c45c525275c44e4 . "./code.cg2js/cg-get-position.fasl")
(#xf77276b91d8efe07cf8474909ced20e0 . "./code.cg2js/cg-trackbar.fasl")
(#x5d609505c922cbdc6f0d4dd5ba443cc1 . "./code.cg2js/cg-selected-object.fasl")
(#x21b040400e197dccf82a2e1708021d82 . "./code.cg2js/cg-list-view.fasl")
(#x9914c08bafd638b0335ba4ea9588284a . "./code.cg2js/cg-html-widget.fasl")
(#xe6f3addb3c069aee193e42eb50d3bd86 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x05c571861515149c009deea03e504772 . "./code.cg2js/cg-text-widget.fasl")
(#x72dceb0b5b47b1f25a2fe55f53b32500 . "./code.idejs/ide-base.fasl")
(#xb17aff3a6c44e8d38f19e12157bd2818 . "./code.idejs/ide-process-browser.fasl")
(#xe079227068e40667c661c3cf70fd1e2d . "./code.idejs/ide-patch-dialog.fasl")
(#xbae50390181345405d4429bd37b7cae6 . "./code.idejs/ide-keyshort.fasl")
(#x7b8d2ad1efe468e1d58c1d2c1b189ac4 . "./code.idejs/ide-window-list.fasl")
(#xc2a84b7ed4db1e516332b6a853bc899a . "./code.idejs/ide.fasl")
(#x4aa6ec551943c758e29c2a5da5585bd2 . "./code.idejs/ide-editor.fasl")
(#xe09d86a49f97fa21ccf6f8940f58a1f9 . "./code.idejs/ide-clipboard.fasl")
(#xf5b78a57e9551a574f50de9c91ba9628 . "./code.idejs/ide-trace.fasl")
(#x04152595a70d9e3e5e9500b62d6c4be1 . "./code.idejs/ide-class-browser.fasl")
(#x1e34ed0659a6946e3fe039ab60591b66 . "./code.idejs/ide-grapher.fasl")
(#x0b92d3d1ace7edfff6acbd4ab69b9b62 . "./code.idejs/ide-apropos.fasl")
(#x1c7542201f214484ac5a7c2283a7b93b . "./code.idejs/ide-navigator.fasl")
(#x812e7159cf263773711295b02cb0fa3b . "./code.idejs/ide-find-definitions.fasl")
(#x2689260dd51094b1042c91c046a4ff9b . "./code.idejs/ide-project.fasl")
(#x9623980af435d32f208e85cedd9663cb . "./code.idejs/ide-class-grapher.fasl")
(#x51aa117ae03dc81a4c5be599e68121b4 . "./code.idejs/ide-acache.fasl")
(#xa8673d2b7b5d442253e115eab536ff8f . "./code.idejs/ide-find-in-files.fasl")
(#x770232e0338078c1358ef94779a6c860 . "./code.idejs/ide-inspector.fasl")
(#xd35c5d40d1b370bedaeb18fa4076052b . "./code.idejs/ide-intro.fasl")
(#x451ae2fc466f265cb30e6cba3f21e323 . "./code.idejs/ide-package-list.fasl")
(#x968428f1b221f2a32ce8f52a014907e6 . "./code.idejs/ide-dev.fasl")
(#x7dc8a98e53d069969922d45c7cec58c6 . "./code.idejs/ide-form.fasl")
(#xe396744af4d34e05e734175c54f8cafc . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
